import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export declare namespace ITWRegistry {
    type DeploymentStruct = {
        deploymentAddress: string;
        chainId: BigNumberish;
    };
    type DeploymentStructOutput = [string, BigNumber] & {
        deploymentAddress: string;
        chainId: BigNumber;
    };
}
export interface ITWRegistryInterface extends utils.Interface {
    functions: {
        "add(address,address,uint256)": FunctionFragment;
        "count(address)": FunctionFragment;
        "getAll(address)": FunctionFragment;
        "remove(address,address,uint256)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "add" | "count" | "getAll" | "remove"): FunctionFragment;
    encodeFunctionData(functionFragment: "add", values: [string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "count", values: [string]): string;
    encodeFunctionData(functionFragment: "getAll", values: [string]): string;
    encodeFunctionData(functionFragment: "remove", values: [string, string, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "add", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "count", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAll", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "remove", data: BytesLike): Result;
    events: {
        "Added(address,address,uint256)": EventFragment;
        "Deleted(address,address,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Added"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Deleted"): EventFragment;
}
export interface AddedEventObject {
    deployer: string;
    deployment: string;
    chainId: BigNumber;
}
export type AddedEvent = TypedEvent<[
    string,
    string,
    BigNumber
], AddedEventObject>;
export type AddedEventFilter = TypedEventFilter<AddedEvent>;
export interface DeletedEventObject {
    deployer: string;
    deployment: string;
    chainId: BigNumber;
}
export type DeletedEvent = TypedEvent<[
    string,
    string,
    BigNumber
], DeletedEventObject>;
export type DeletedEventFilter = TypedEventFilter<DeletedEvent>;
export interface ITWRegistry extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ITWRegistryInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        add(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        count(_deployer: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            deploymentCount: BigNumber;
        }>;
        getAll(_deployer: string, overrides?: CallOverrides): Promise<[
            ITWRegistry.DeploymentStructOutput[]
        ] & {
            allDeployments: ITWRegistry.DeploymentStructOutput[];
        }>;
        remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    add(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    count(_deployer: string, overrides?: CallOverrides): Promise<BigNumber>;
    getAll(_deployer: string, overrides?: CallOverrides): Promise<ITWRegistry.DeploymentStructOutput[]>;
    remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        add(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: CallOverrides): Promise<void>;
        count(_deployer: string, overrides?: CallOverrides): Promise<BigNumber>;
        getAll(_deployer: string, overrides?: CallOverrides): Promise<ITWRegistry.DeploymentStructOutput[]>;
        remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "Added(address,address,uint256)"(deployer?: string | null, deployment?: string | null, chainId?: BigNumberish | null): AddedEventFilter;
        Added(deployer?: string | null, deployment?: string | null, chainId?: BigNumberish | null): AddedEventFilter;
        "Deleted(address,address,uint256)"(deployer?: string | null, deployment?: string | null, chainId?: BigNumberish | null): DeletedEventFilter;
        Deleted(deployer?: string | null, deployment?: string | null, chainId?: BigNumberish | null): DeletedEventFilter;
    };
    estimateGas: {
        add(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        count(_deployer: string, overrides?: CallOverrides): Promise<BigNumber>;
        getAll(_deployer: string, overrides?: CallOverrides): Promise<BigNumber>;
        remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        add(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        count(_deployer: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getAll(_deployer: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        remove(_deployer: string, _deployment: string, _chainId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=ITWRegistry.d.ts.map