import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export declare namespace ISignatureAction {
    type GenericRequestStruct = {
        validityStartTimestamp: BigNumberish;
        validityEndTimestamp: BigNumberish;
        uid: BytesLike;
        data: BytesLike;
    };
    type GenericRequestStructOutput = [
        BigNumber,
        BigNumber,
        string,
        string
    ] & {
        validityStartTimestamp: BigNumber;
        validityEndTimestamp: BigNumber;
        uid: string;
        data: string;
    };
}
export interface SignatureActionInterface extends utils.Interface {
    functions: {
        "verify((uint128,uint128,bytes32,bytes),bytes)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "verify"): FunctionFragment;
    encodeFunctionData(functionFragment: "verify", values: [ISignatureAction.GenericRequestStruct, BytesLike]): string;
    decodeFunctionResult(functionFragment: "verify", data: BytesLike): Result;
    events: {
        "RequestExecuted(address,address,tuple)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "RequestExecuted"): EventFragment;
}
export interface RequestExecutedEventObject {
    user: string;
    signer: string;
    _req: ISignatureAction.GenericRequestStructOutput;
}
export type RequestExecutedEvent = TypedEvent<[
    string,
    string,
    ISignatureAction.GenericRequestStructOutput
], RequestExecutedEventObject>;
export type RequestExecutedEventFilter = TypedEventFilter<RequestExecutedEvent>;
export interface SignatureAction extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: SignatureActionInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        verify(_req: ISignatureAction.GenericRequestStruct, _signature: BytesLike, overrides?: CallOverrides): Promise<[boolean, string] & {
            success: boolean;
            signer: string;
        }>;
    };
    verify(_req: ISignatureAction.GenericRequestStruct, _signature: BytesLike, overrides?: CallOverrides): Promise<[boolean, string] & {
        success: boolean;
        signer: string;
    }>;
    callStatic: {
        verify(_req: ISignatureAction.GenericRequestStruct, _signature: BytesLike, overrides?: CallOverrides): Promise<[boolean, string] & {
            success: boolean;
            signer: string;
        }>;
    };
    filters: {
        "RequestExecuted(address,address,tuple)"(user?: string | null, signer?: string | null, _req?: null): RequestExecutedEventFilter;
        RequestExecuted(user?: string | null, signer?: string | null, _req?: null): RequestExecutedEventFilter;
    };
    estimateGas: {
        verify(_req: ISignatureAction.GenericRequestStruct, _signature: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        verify(_req: ISignatureAction.GenericRequestStruct, _signature: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=SignatureAction.d.ts.map