import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface Staking721UpgradeableInterface extends utils.Interface {
    functions: {
        "claimRewards()": FunctionFragment;
        "getRewardTokenBalance()": FunctionFragment;
        "getRewardsPerUnitTime()": FunctionFragment;
        "getStakeInfo(address)": FunctionFragment;
        "getTimeUnit()": FunctionFragment;
        "indexedTokens(uint256)": FunctionFragment;
        "isIndexed(uint256)": FunctionFragment;
        "setRewardsPerUnitTime(uint256)": FunctionFragment;
        "setTimeUnit(uint256)": FunctionFragment;
        "stake(uint256[])": FunctionFragment;
        "stakerAddress(uint256)": FunctionFragment;
        "stakers(address)": FunctionFragment;
        "stakersArray(uint256)": FunctionFragment;
        "stakingToken()": FunctionFragment;
        "withdraw(uint256[])": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "claimRewards" | "getRewardTokenBalance" | "getRewardsPerUnitTime" | "getStakeInfo" | "getTimeUnit" | "indexedTokens" | "isIndexed" | "setRewardsPerUnitTime" | "setTimeUnit" | "stake" | "stakerAddress" | "stakers" | "stakersArray" | "stakingToken" | "withdraw"): FunctionFragment;
    encodeFunctionData(functionFragment: "claimRewards", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRewardTokenBalance", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRewardsPerUnitTime", values?: undefined): string;
    encodeFunctionData(functionFragment: "getStakeInfo", values: [string]): string;
    encodeFunctionData(functionFragment: "getTimeUnit", values?: undefined): string;
    encodeFunctionData(functionFragment: "indexedTokens", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "isIndexed", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setRewardsPerUnitTime", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setTimeUnit", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "stake", values: [BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "stakerAddress", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "stakers", values: [string]): string;
    encodeFunctionData(functionFragment: "stakersArray", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "stakingToken", values?: undefined): string;
    encodeFunctionData(functionFragment: "withdraw", values: [BigNumberish[]]): string;
    decodeFunctionResult(functionFragment: "claimRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRewardTokenBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRewardsPerUnitTime", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getStakeInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getTimeUnit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "indexedTokens", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isIndexed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRewardsPerUnitTime", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setTimeUnit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stakerAddress", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stakers", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stakersArray", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stakingToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdraw", data: BytesLike): Result;
    events: {
        "Initialized(uint8)": EventFragment;
        "RewardsClaimed(address,uint256)": EventFragment;
        "TokensStaked(address,uint256[])": EventFragment;
        "TokensWithdrawn(address,uint256[])": EventFragment;
        "UpdatedRewardsPerUnitTime(uint256,uint256)": EventFragment;
        "UpdatedTimeUnit(uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Initialized"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RewardsClaimed"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "TokensStaked"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "TokensWithdrawn"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UpdatedRewardsPerUnitTime"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UpdatedTimeUnit"): EventFragment;
}
export interface InitializedEventObject {
    version: number;
}
export type InitializedEvent = TypedEvent<[number], InitializedEventObject>;
export type InitializedEventFilter = TypedEventFilter<InitializedEvent>;
export interface RewardsClaimedEventObject {
    staker: string;
    rewardAmount: BigNumber;
}
export type RewardsClaimedEvent = TypedEvent<[
    string,
    BigNumber
], RewardsClaimedEventObject>;
export type RewardsClaimedEventFilter = TypedEventFilter<RewardsClaimedEvent>;
export interface TokensStakedEventObject {
    staker: string;
    tokenIds: BigNumber[];
}
export type TokensStakedEvent = TypedEvent<[
    string,
    BigNumber[]
], TokensStakedEventObject>;
export type TokensStakedEventFilter = TypedEventFilter<TokensStakedEvent>;
export interface TokensWithdrawnEventObject {
    staker: string;
    tokenIds: BigNumber[];
}
export type TokensWithdrawnEvent = TypedEvent<[
    string,
    BigNumber[]
], TokensWithdrawnEventObject>;
export type TokensWithdrawnEventFilter = TypedEventFilter<TokensWithdrawnEvent>;
export interface UpdatedRewardsPerUnitTimeEventObject {
    oldRewardsPerUnitTime: BigNumber;
    newRewardsPerUnitTime: BigNumber;
}
export type UpdatedRewardsPerUnitTimeEvent = TypedEvent<[
    BigNumber,
    BigNumber
], UpdatedRewardsPerUnitTimeEventObject>;
export type UpdatedRewardsPerUnitTimeEventFilter = TypedEventFilter<UpdatedRewardsPerUnitTimeEvent>;
export interface UpdatedTimeUnitEventObject {
    oldTimeUnit: BigNumber;
    newTimeUnit: BigNumber;
}
export type UpdatedTimeUnitEvent = TypedEvent<[
    BigNumber,
    BigNumber
], UpdatedTimeUnitEventObject>;
export type UpdatedTimeUnitEventFilter = TypedEventFilter<UpdatedTimeUnitEvent>;
export interface Staking721Upgradeable extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: Staking721UpgradeableInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        claimRewards(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        getRewardTokenBalance(overrides?: CallOverrides): Promise<[BigNumber] & {
            _rewardsAvailableInContract: BigNumber;
        }>;
        getRewardsPerUnitTime(overrides?: CallOverrides): Promise<[BigNumber] & {
            _rewardsPerUnitTime: BigNumber;
        }>;
        getStakeInfo(_staker: string, overrides?: CallOverrides): Promise<[
            BigNumber[],
            BigNumber
        ] & {
            _tokensStaked: BigNumber[];
            _rewards: BigNumber;
        }>;
        getTimeUnit(overrides?: CallOverrides): Promise<[BigNumber] & {
            _timeUnit: BigNumber;
        }>;
        indexedTokens(arg0: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        isIndexed(arg0: BigNumberish, overrides?: CallOverrides): Promise<[boolean]>;
        setRewardsPerUnitTime(_rewardsPerUnitTime: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setTimeUnit(_timeUnit: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        stake(_tokenIds: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        stakerAddress(arg0: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        stakers(arg0: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber
        ] & {
            amountStaked: BigNumber;
            conditionIdOflastUpdate: BigNumber;
            timeOfLastUpdate: BigNumber;
            unclaimedRewards: BigNumber;
        }>;
        stakersArray(arg0: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        stakingToken(overrides?: CallOverrides): Promise<[string]>;
        withdraw(_tokenIds: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    claimRewards(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    getRewardTokenBalance(overrides?: CallOverrides): Promise<BigNumber>;
    getRewardsPerUnitTime(overrides?: CallOverrides): Promise<BigNumber>;
    getStakeInfo(_staker: string, overrides?: CallOverrides): Promise<[
        BigNumber[],
        BigNumber
    ] & {
        _tokensStaked: BigNumber[];
        _rewards: BigNumber;
    }>;
    getTimeUnit(overrides?: CallOverrides): Promise<BigNumber>;
    indexedTokens(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    isIndexed(arg0: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
    setRewardsPerUnitTime(_rewardsPerUnitTime: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setTimeUnit(_timeUnit: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    stake(_tokenIds: BigNumberish[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    stakerAddress(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
    stakers(arg0: string, overrides?: CallOverrides): Promise<[
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber
    ] & {
        amountStaked: BigNumber;
        conditionIdOflastUpdate: BigNumber;
        timeOfLastUpdate: BigNumber;
        unclaimedRewards: BigNumber;
    }>;
    stakersArray(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
    stakingToken(overrides?: CallOverrides): Promise<string>;
    withdraw(_tokenIds: BigNumberish[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        claimRewards(overrides?: CallOverrides): Promise<void>;
        getRewardTokenBalance(overrides?: CallOverrides): Promise<BigNumber>;
        getRewardsPerUnitTime(overrides?: CallOverrides): Promise<BigNumber>;
        getStakeInfo(_staker: string, overrides?: CallOverrides): Promise<[
            BigNumber[],
            BigNumber
        ] & {
            _tokensStaked: BigNumber[];
            _rewards: BigNumber;
        }>;
        getTimeUnit(overrides?: CallOverrides): Promise<BigNumber>;
        indexedTokens(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        isIndexed(arg0: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
        setRewardsPerUnitTime(_rewardsPerUnitTime: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setTimeUnit(_timeUnit: BigNumberish, overrides?: CallOverrides): Promise<void>;
        stake(_tokenIds: BigNumberish[], overrides?: CallOverrides): Promise<void>;
        stakerAddress(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
        stakers(arg0: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber
        ] & {
            amountStaked: BigNumber;
            conditionIdOflastUpdate: BigNumber;
            timeOfLastUpdate: BigNumber;
            unclaimedRewards: BigNumber;
        }>;
        stakersArray(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
        stakingToken(overrides?: CallOverrides): Promise<string>;
        withdraw(_tokenIds: BigNumberish[], overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "Initialized(uint8)"(version?: null): InitializedEventFilter;
        Initialized(version?: null): InitializedEventFilter;
        "RewardsClaimed(address,uint256)"(staker?: string | null, rewardAmount?: null): RewardsClaimedEventFilter;
        RewardsClaimed(staker?: string | null, rewardAmount?: null): RewardsClaimedEventFilter;
        "TokensStaked(address,uint256[])"(staker?: string | null, tokenIds?: BigNumberish[] | null): TokensStakedEventFilter;
        TokensStaked(staker?: string | null, tokenIds?: BigNumberish[] | null): TokensStakedEventFilter;
        "TokensWithdrawn(address,uint256[])"(staker?: string | null, tokenIds?: BigNumberish[] | null): TokensWithdrawnEventFilter;
        TokensWithdrawn(staker?: string | null, tokenIds?: BigNumberish[] | null): TokensWithdrawnEventFilter;
        "UpdatedRewardsPerUnitTime(uint256,uint256)"(oldRewardsPerUnitTime?: null, newRewardsPerUnitTime?: null): UpdatedRewardsPerUnitTimeEventFilter;
        UpdatedRewardsPerUnitTime(oldRewardsPerUnitTime?: null, newRewardsPerUnitTime?: null): UpdatedRewardsPerUnitTimeEventFilter;
        "UpdatedTimeUnit(uint256,uint256)"(oldTimeUnit?: null, newTimeUnit?: null): UpdatedTimeUnitEventFilter;
        UpdatedTimeUnit(oldTimeUnit?: null, newTimeUnit?: null): UpdatedTimeUnitEventFilter;
    };
    estimateGas: {
        claimRewards(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        getRewardTokenBalance(overrides?: CallOverrides): Promise<BigNumber>;
        getRewardsPerUnitTime(overrides?: CallOverrides): Promise<BigNumber>;
        getStakeInfo(_staker: string, overrides?: CallOverrides): Promise<BigNumber>;
        getTimeUnit(overrides?: CallOverrides): Promise<BigNumber>;
        indexedTokens(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        isIndexed(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        setRewardsPerUnitTime(_rewardsPerUnitTime: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setTimeUnit(_timeUnit: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        stake(_tokenIds: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        stakerAddress(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        stakers(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        stakersArray(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        stakingToken(overrides?: CallOverrides): Promise<BigNumber>;
        withdraw(_tokenIds: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        claimRewards(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        getRewardTokenBalance(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRewardsPerUnitTime(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getStakeInfo(_staker: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getTimeUnit(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        indexedTokens(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isIndexed(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setRewardsPerUnitTime(_rewardsPerUnitTime: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setTimeUnit(_timeUnit: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        stake(_tokenIds: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        stakerAddress(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        stakers(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        stakersArray(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        stakingToken(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        withdraw(_tokenIds: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=Staking721Upgradeable.d.ts.map